@@ -275,7 +275,7 @@ class DotImage:
                 self.image = working_image
         else:
             self.z_method = 'full'
-            self.z_use = np.arange(0, working_images.slices)
+            self.z_use = np.arange(0, working_image.slices)
             self.image = working_image
         
         
