@@ -40,6 +40,7 @@ def fetch_image(data_dir, cycle, position, hyb_pattern='HybCycle_(\d+)$', im_pre
     im_pattern = '^' + im_prefix + 'MMStack_Pos(\d+)(.*)'
     
     image = None
+    found_dir = False
     
     for f in os.scandir(data_dir):
         cycle_search = re.search(hyb_pattern, f.name)
@@ -54,12 +55,16 @@ def fetch_image(data_dir, cycle, position, hyb_pattern='HybCycle_(\d+)$', im_pre
 
                 return None
             
+            found_dir = True
             break # break out of the folder/cycle loop
         
         else:
             
             continue # jump to the next folder if this one doesn't match
-            
+    
+    if not found_dir:
+        return None
+    
     for g in os.scandir(f.path):
         pos_search = re.search(im_pattern, g.name)
             
